Bottle  plugin for ORM Peewee integrated
=========================================

A simple plugin for Bottle microframework 
for integrating ORM peewee in bottle

--
wbr// Spouk
mail: spouk@spouk.ru



